<?php
/**
* 륤󥿡ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

interface IConfigProvider extends IObject
{
	/*
	 *
	 */
	public function load( $config_root, $config_name );

}

return __FILE__;